dupin.preprocessing.supervised
----------------------------------------

.. rubric:: Overview

.. py:currentmodule:: dupin.preprocessing.supervised

.. autosummary::
    :nosignatures:

    window_iter
    Window

.. rubric:: Details

.. automodule:: dupin.preprocessing.supervised
    :synopsis: Supervised learning techniques for signal processing.
    :members: window_iter,
        Window
